<?php

/*

	Plugin Name: Ephemeris
	Plugin URI: http://www.joeswebtools.com/wordpress-plugins/ephemeris/
	Description: Adds a sidebar widget that display the current astrological sky.
	Version: 1.0
	Author: Joe's Web Tools
	Author URI: http://www.joeswebtools.com/

	Copyright 2009 Philippe Paquet (email: philippe@paquet.net)

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
	
	If you are unable to comply with the terms of the GNU General Public License,
	contact the copyright holder for a commercial license.

*/



function widget_ephemeris_get_plugin_url() {

	// Try the API introduced in Wordpress 2.6
	if(function_exists('plugins_url')) {
		return trailingslashit(plugins_url(basename(dirname(__FILE__))));
	}

	$path = dirname(__FILE__);
	$path = str_replace('\\', '/', $path);
	$path = trailingslashit(get_bloginfo('wpurl')) . trailingslashit(substr($path, strpos($path, 'wp-content/')));

	return $path;
}



function widget_ephemeris_normalize($v) {
	$v -= floor($v);
	if($v < 0) {
		$v += 1;
	}
	return $v;
}



function widget_ephemeris_display($args) {

	// Load language file
	$current_locale = get_locale();
	if(!empty($current_locale)) {
		$mo_file = dirname(__FILE__) . '/languages/ephemeris-' . $current_locale . ".mo";
		if(@file_exists($mo_file) && is_readable($mo_file)) {
			load_textdomain('ephemeris', $mo_file);
		}
	}

	// Get title
	$title = htmlspecialchars(get_option('widget_ephemeris_title'), ENT_QUOTES);

	// Help widget to conform to the active theme: before_widget, before_title and after_title
	extract($args);
	echo $before_widget . $before_title . $title . $after_title;

	// Get date
	$y = date('Y');
	$m = date('n');
	$d = date('j');

	// Calculate julian day
	$yy = $y - floor((12 - $m) / 10);
	$mm = $m + 9;
	if($mm >= 12) {
		$mm = $mm - 12;
	}

	$k1 = floor(365.25 * ($yy + 4712));
	$k2 = floor(30.6 * $mm + 0.5);
	$k3 = floor(floor(($yy / 100) + 49) * 0.75) - 38;

	$jd = $k1 + $k2 + $d + 59;
	if($jd > 2299160) {
		$jd = $jd - $k3;
	}

	// Calculate the moon's phase
	$ip = widget_ephemeris_normalize(($jd - 2451550.1) / 29.530588853);
	$ag = $ip * 29.53;

	if($ag < 1.84566) {
		$moon_phase = __('New Moon', 'ephemeris');
		$moon_phase_image = widget_ephemeris_get_plugin_url() . 'images/moon/new_moon';
	}
    else if($ag < 5.53699) {
    	$moon_phase = __('Waxing Crescent Moon', 'ephemeris');
		$moon_phase_image = widget_ephemeris_get_plugin_url() . 'images/moon/waxing_crescent_moon';
    }
    else if($ag < 9.22831) {
		$moon_phase = __('First Quarter Moon', 'ephemeris');
		$moon_phase_image = widget_ephemeris_get_plugin_url() . 'images/moon/first_quarter_moon';
	}
	else if($ag < 12.91963) {
		$moon_phase = __('Waxing Gibbous Moon', 'ephemeris');
		$moon_phase_image = widget_ephemeris_get_plugin_url() . 'images/moon/waxing_gibbous_moon';
	}
	else if($ag < 16.61096) {
		$moon_phase = __('Full Moon', 'ephemeris');
		$moon_phase_image = widget_ephemeris_get_plugin_url() . 'images/moon/full_moon';
	}
	else if($ag < 20.30228) {
		$moon_phase = __('Waning Gibbous Moon', 'ephemeris');
		$moon_phase_image = widget_ephemeris_get_plugin_url() . 'images/moon/waning_gibbous_moon';
	}
	else if($ag < 23.99361) {
		$moon_phase = __('Third Quarter Moon', 'ephemeris');
		$moon_phase_image = widget_ephemeris_get_plugin_url() . 'images/moon/third_quarter_moon';
	}
	else if($ag < 27.68493) {
		$moon_phase = __('Waning Crescent Moon', 'ephemeris');
		$moon_phase_image = widget_ephemeris_get_plugin_url() . 'images/moon/waning_crescent_moon';
	}
	else {
		$moon_phase = __('New Moon', 'ephemeris');
		$moon_phase_image = widget_ephemeris_get_plugin_url() . 'images/moon/new_moon';
	}

	// Convert phase to radians
	$ip = $ip * 2 * pi();

	// Calculate moon's distance
	$dp = 2 * pi() * widget_ephemeris_normalize(($jd - 2451562.2) / 27.55454988);
	$di = 60.4 - 3.3 * cos($dp) - 0.6 * cos(2 * $ip - $dp) - 0.5 * cos(2 * $ip);

	// Calculate moon's ecliptic latitude
	$np = 2 * pi() * widget_ephemeris_normalize(($jd - 2451565.2) / 27.212220817);
	$la = 5.1 * sin($np);

	// Calculate moon's ecliptic longitude
	$rp = widget_ephemeris_normalize(($jd - 2451555.8) / 27.321582241);
	$lo = 360 * $rp + 6.3 * sin($dp) + 1.3 * sin(2 * $ip - $dp) + 0.7 * sin(2 * $ip);

	// Calculate moon's zodiac sign
	if($lo < 30) {
		$moon_zodiac = __('Aries', 'ephemeris');
		$moon_zodiac_image = widget_ephemeris_get_plugin_url() . 'images/zodiac/aries';
	}
	else if($lo < 60) {
		$moon_zodiac = __('Taurus', 'ephemeris');
		$moon_zodiac_image = widget_ephemeris_get_plugin_url() . 'images/zodiac/taurus';
	}
	else if($lo < 90) {
		$moon_zodiac = __('Gemini', 'ephemeris');
		$moon_zodiac_image = widget_ephemeris_get_plugin_url() . 'images/zodiac/gemini';
	}
	else if($lo < 120) {
		$moon_zodiac = __('Cancer', 'ephemeris');
		$moon_zodiac_image = widget_ephemeris_get_plugin_url() . 'images/zodiac/cancer';
	}
	else if($lo < 150) {
		$moon_zodiac = __('Leo', 'ephemeris');
		$moon_zodiac_image = widget_ephemeris_get_plugin_url() . 'images/zodiac/leo';
	}
	else if($lo < 180) {
		$moon_zodiac = __('Virgo', 'ephemeris');
		$moon_zodiac_image = widget_ephemeris_get_plugin_url() . 'images/zodiac/virgo';
	}
	else if($lo < 210) {
    	$moon_zodiac = __('Libra', 'ephemeris');
		$moon_zodiac_image = widget_ephemeris_get_plugin_url() . 'images/zodiac/libra';
	}
    else if($lo < 240) {
    	$moon_zodiac = __('Scorpio', 'ephemeris');
		$moon_zodiac_image = widget_ephemeris_get_plugin_url() . 'images/zodiac/scorpio';
    }
    else if($lo < 270) {
    	$moon_zodiac = __('Sagittarius', 'ephemeris');
		$moon_zodiac_image = widget_ephemeris_get_plugin_url() . 'images/zodiac/sagittarius';
    }
    else if($lo < 300) {
    	$moon_zodiac = __('Capricorn', 'ephemeris');
		$moon_zodiac_image = widget_ephemeris_get_plugin_url() . 'images/zodiac/capricorn';
    }
    else if($lo < 330) {
		$moon_zodiac = __('Aquarius', 'ephemeris');
		$moon_zodiac_image = widget_ephemeris_get_plugin_url() . 'images/zodiac/aquarius';
    }
	else {
		$moon_zodiac = __('Pisces', 'ephemeris');
		$moon_zodiac_image = widget_ephemeris_get_plugin_url() . 'images/zodiac/pisces';
	}

	// Age
	$age = floor($ag);

	// Distance
	$distance = round(100 * $di) / 100;

	// Ecliptic latitude
	$latitude = round(100 * $la) / 100;

	// Ecliptic longitude
	$longitude = round(100 * $lo) / 100;
	if($longitude > 360) {
		$longitude -= 360;
	}
	$moon_zodiac_longitude = round($longitude % 30);

	// Calculate sun's zodiac sign
	if((($m == 1) && ($d >= 20)) || (($m == 2) && ($d <= 18))) {
		$sun_zodiac = __('Aquarius', 'ephemeris');
		$sun_zodiac_image = widget_ephemeris_get_plugin_url() . 'images/zodiac/aquarius';
	} else if((($m == 2) && ($d >= 19)) || (($m == 3) && ($d <= 20))) {
		$sun_zodiac = __('Pisces', 'ephemeris');
		$sun_zodiac_image = widget_ephemeris_get_plugin_url() . 'images/zodiac/pisces';
	} else if((($m == 3) && ($d >= 21)) || (($m == 4) && ($d <= 19))) {
		$sun_zodiac = __('Aries', 'ephemeris');
		$sun_zodiac_image = widget_ephemeris_get_plugin_url() . 'images/zodiac/aries';
	} else if((($m == 4) && ($d >= 20)) || (($m == 5) && ($d <= 20))) {
		$sun_zodiac = __('Taurus', 'ephemeris');
		$sun_zodiac_image = widget_ephemeris_get_plugin_url() . 'images/zodiac/taurus';
	} else if((($m == 5) && ($d >= 21)) || (($m == 6) && ($d <= 21))) {
		$sun_zodiac = __('Gemini', 'ephemeris');
		$sun_zodiac_image = widget_ephemeris_get_plugin_url() . 'images/zodiac/gemini';
	} else if((($m == 6) && ($d >= 22)) || (($m == 7) && ($d <= 22))) {
		$sun_zodiac = __('Cancer', 'ephemeris');
		$sun_zodiac_image = widget_ephemeris_get_plugin_url() . 'images/zodiac/cancer';
	} else if((($m == 7) && ($d >= 23)) || (($m == 8) && ($d <= 22))) {
		$sun_zodiac = __('Leo', 'ephemeris');
		$sun_zodiac_image = widget_ephemeris_get_plugin_url() . 'images/zodiac/leo';
	} else if((($m == 8) && ($d >= 23)) || (($m == 9) && ($d <= 22))) {
		$sun_zodiac = __('Virgo', 'ephemeris');
		$sun_zodiac_image = widget_ephemeris_get_plugin_url() . 'images/zodiac/virgo';
	} else if((($m == 9) && ($d >= 23)) || (($m == 10) && ($d <= 22))) {
    	$sun_zodiac = __('Libra', 'ephemeris');
		$sun_zodiac_image = widget_ephemeris_get_plugin_url() . 'images/zodiac/libra';
	} else if((($m == 10) && ($d >= 23)) || (($m == 11) && ($d <= 21))) {
    	$sun_zodiac = __('Scorpio', 'ephemeris');
		$sun_zodiac_image = widget_ephemeris_get_plugin_url() . 'images/zodiac/scorpio';
	} else if((($m == 11) && ($d >= 22)) || (($m == 12) && ($d <= 21))) {
    	$sun_zodiac = __('Sagittarius', 'ephemeris');
		$sun_zodiac_image = widget_ephemeris_get_plugin_url() . 'images/zodiac/sagittarius';
	} else if((($m == 12) && ($d >= 22)) || (($m == 1) && ($d <= 19))) {
    	$sun_zodiac = __('Capricorn', 'ephemeris');
		$sun_zodiac_image = widget_ephemeris_get_plugin_url() . 'images/zodiac/capricorn';
	}

	// Ecliptic longitude
	if(date('L') == '1')
	{
		$sun_zodiac_longitude = (366 / 360) * (date('z') + 20);
	}
	else
	{
		$sun_zodiac_longitude = (365 / 360) * (date('z') + 20);
	}
	$sun_zodiac_longitude = round($sun_zodiac_longitude % 30);

	// Display sun zodiac
	switch(get_option('widget_ephemeris_sun_zodiac')) {

	case 'large':
		echo '<div style="text-align: center;">';
		echo 	'<img src="' . $sun_zodiac_image . '_110x110.png" alt="' . $sun_zodiac . '" title="' . $sun_zodiac . '" width="110" height="110" /><br />';
		printf	(__('Sun in %s', 'ephemeris'), $sun_zodiac);
		echo '</div>';
		break;

	case 'small':
		if('left' == get_option('widget_ephemeris_alignment')) {
			echo '<table border="0" width="100%">';
			echo 	'<tr>';
			echo 		'<td width="60">';
			echo 			'<img src="' . $sun_zodiac_image . '_55x55.png" alt="' . $sun_zodiac . '" title="' . $sun_zodiac . '" width="55" height="55" /><br />';
			echo 		'</td>';
			echo 		'<td align="left">';
			printf			(__('Sun in %s', 'ephemeris'), $sun_zodiac);
			echo 			'<br />';
			printf			(__ngettext('%d degree', '%d degrees', $sun_zodiac_longitude, 'ephemeris'), $sun_zodiac_longitude);
			echo 		'</td>';
			echo 	'</tr>';
			echo '</table>';
		} else {
			echo '<table border="0" width="100%">';
			echo 	'<tr>';
			echo 		'<td align="right">';
			printf			(__('Sun in %s', 'ephemeris'), $sun_zodiac);
			echo 			'<br />';
			printf			(__ngettext('%d degree', '%d degrees', $sun_zodiac_longitude, 'ephemeris'), $sun_zodiac_longitude);
			echo 		'</td>';
			echo 		'<td width="60">';
			echo 			'<img src="' . $sun_zodiac_image . '_55x55.png" alt="' . $sun_zodiac . '" title="' . $sun_zodiac . '" width="55" height="55" /><br />';
			echo 		'</td>';
			echo 	'</tr>';
			echo '</table>';
		}
		break;
	}

	// Display moon zodiac
	switch(get_option('widget_ephemeris_moon_zodiac')) {

	case 'large':
		echo '<div style="text-align: center;">';
		echo 	'<img src="' . $moon_zodiac_image . '_110x110.png" alt="' . $moon_zodiac . '" title="' . $moon_zodiac . '" width="110" height="110" /><br />';
		printf	(__('Moon in %s', 'ephemeris'), $moon_zodiac);
		echo 	'<br />';
		printf	(__ngettext('%d degree', '%d degrees', $moon_zodiac_longitude, 'ephemeris'), $moon_zodiac_longitude);
		echo '</div>';
		break;

	case 'small':
		if('left' == get_option('widget_ephemeris_alignment')) {
			echo '<table border="0" width="100%">';
			echo 	'<tr>';
			echo 		'<td width="60">';
			echo 			'<img src="' . $moon_zodiac_image . '_55x55.png" alt="' . $moon_zodiac . '" title="' . $moon_zodiac . '" width="55" height="55" /><br />';
			echo 		'</td>';
			echo 		'<td align="left">';
			printf			(__('Moon in %s', 'ephemeris'), $moon_zodiac);
			echo 			'<br />';
			printf			(__ngettext('%d degree', '%d degrees', $moon_zodiac_longitude, 'ephemeris'), $moon_zodiac_longitude);
			echo 		'</td>';
			echo 	'</tr>';
			echo '</table>';
		} else {
			echo '<table border="0" width="100%">';
			echo 	'<tr>';
			echo 		'<td align="right">';
			printf			(__('Moon in %s', 'ephemeris'), $moon_zodiac);
			echo 			'<br />';
			printf			(__ngettext('%d degree', '%d degrees', $moon_zodiac_longitude, 'ephemeris'), $moon_zodiac_longitude);
			echo 		'</td>';
			echo 		'<td width="60">';
			echo 			'<img src="' . $moon_zodiac_image . '_55x55.png" alt="' . $moon_zodiac . '" title="' . $moon_zodiac . '" width="55" height="55" /><br />';
			echo 		'</td>';
			echo 	'</tr>';
			echo '</table>';
		}
		break;
	}

	// Display moon phase
	switch(get_option('widget_ephemeris_moon_phase')) {

	case 'large':
		echo '<div style="text-align: center;">';
		echo 	'<img src="' . $moon_phase_image . '_110x110.png" alt="' . $moon_phase . '" title="' . $moon_phase . '" width="110" height="110" /><br />';
		echo 	$moon_phase . '<br />';
		printf	(__ngettext('%d day old', '%d days old', $age, 'ephemeris'), $age);
		echo 	'<br />';
		echo '</div>';
		break;

	case 'small':
		if('left' == get_option('widget_ephemeris_alignment')) {
			echo '<table border="0" width="100%">';
			echo 	'<tr>';
			echo 		'<td width="60">';
			echo 			'<img src="' . $moon_phase_image . '_55x55.png" alt="' . $moon_phase . '" title="' . $moon_phase . '" width="55" height="55" /><br />';
			echo 		'</td>';
			echo 		'<td align="left">';
			echo 			$moon_phase . '<br />';
			printf			(__ngettext('%d day old', '%d days old', $age, 'ephemeris'), $age);
			echo 		'</td>';
			echo 	'</tr>';
			echo '</table>';
		} else {
			echo '<table border="0" width="100%">';
			echo 	'<tr>';
			echo 		'<td align="right">';
			echo 			$moon_phase . '<br />';
			printf			(__ngettext('%d day old', '%d days old', $age, 'ephemeris'), $age);
			echo 		'</td>';
			echo 		'<td width="60">';
			echo 			'<img src="' . $moon_phase_image . '_55x55.png" alt="' . $moon_phase . '" title="' . $moon_phase . '" width="55" height="55" /><br />';
			echo 		'</td>';
			echo 	'</tr>';
			echo '</table>';
		}
		break;
	}

	// Display Joe's link
	if('left' == get_option('widget_ephemeris_alignment')) {
		echo '<div style="text-align: right;"><font face="arial" size="-3"><a href="http://www.joeswebtools.com/wordpress-plugins/ephemeris/">Joe\'s</a></font></div>';
	} else {
		echo '<div style="text-align: left;"><font face="arial" size="-3"><a href="http://www.joeswebtools.com/wordpress-plugins/ephemeris/">Joe\'s</a></font></div>';
	}

	// Help widget to conform to the active theme: after_widget
	echo $after_widget;
}



function widget_ephemeris_control() {

	// Load language file
	$current_locale = get_locale();
	if(!empty($current_locale)) {
		$mo_file = dirname(__FILE__) . '/languages/ephemeris-' . $current_locale . ".mo";
		if(@file_exists($mo_file) && is_readable($mo_file)) {
			load_textdomain('ephemeris', $mo_file);
		}
	}

	// Update options if the form was posted
	if($_POST['widget-ephemeris-submit']) {

		// Title
		update_option('widget_ephemeris_title', strip_tags(stripslashes($_POST['widget-ephemeris-title'])));

		// Alignment
		update_option('widget_ephemeris_alignment', $_POST['widget-ephemeris-alignment']);

		// Moon phase
		update_option('widget_ephemeris_moon_phase', $_POST['widget-ephemeris-moon-phase']);

		// Moon zodiac
		update_option('widget_ephemeris_moon_zodiac', $_POST['widget-ephemeris-moon-zodiac']);

		// Sun zodiac
		update_option('widget_ephemeris_sun_zodiac', $_POST['widget-ephemeris-sun-zodiac']);
	}

	// Title
	$title = htmlspecialchars(get_option('widget_ephemeris_title'), ENT_QUOTES);

	// Alignment
	switch(get_option('widget_ephemeris_alignment')) {

	case 'left':
		$alignment = '<option value="left" selected="selected">' . __('Left', 'ephemeris') . '</option><option value="right">' . __('Right', 'ephemeris') . '</option>';
		break;

	case 'right':
		$alignment = '<option value="left">' . __('Left', 'ephemeris') . '</option><option value="right" selected="selected">' . __('Right', 'ephemeris') . '</option>';
		break;
	}

	// Sun zodiac
	switch(get_option('widget_ephemeris_sun_zodiac')) {

	case 'large':
		$sun_zodiac = '<option value="large" selected="selected">' . __('Large', 'ephemeris') . '</option><option value="small">' . __('Small', 'ephemeris') . '</option><option value="hide">' . __('Hide', 'ephemeris') . '</option>';
		break;

	case 'small':
		$sun_zodiac = '<option value="large">' . __('Large', 'ephemeris') . '</option><option value="small" selected="selected">' . __('Small', 'ephemeris') . '</option><option value="hide">' . __('Hide', 'ephemeris') . '</option>';
		break;

	case 'hide':
		$sun_zodiac = '<option value="large">' . __('Large', 'ephemeris') . '</option><option value="small">' . __('Small', 'ephemeris') . '</option><option value="hide" selected="selected">' . __('Hide', 'ephemeris') . '</option>';
		break;
	}

	// Moon zodiac
	switch(get_option('widget_ephemeris_moon_zodiac')) {

	case 'large':
		$moon_zodiac = '<option value="large" selected="selected">' . __('Large', 'ephemeris') . '</option><option value="small">' . __('Small', 'ephemeris') . '</option><option value="hide">' . __('Hide', 'ephemeris') . '</option>';
		break;

	case 'small':
		$moon_zodiac = '<option value="large">' . __('Large', 'ephemeris') . '</option><option value="small" selected="selected">' . __('Small', 'ephemeris') . '</option><option value="hide">' . __('Hide', 'ephemeris') . '</option>';
		break;

	case 'hide':
		$moon_zodiac = '<option value="large">' . __('Large', 'ephemeris') . '</option><option value="small">' . __('Small', 'ephemeris') . '</option><option value="hide" selected="selected">' . __('Hide', 'ephemeris') . '</option>';
		break;
	}

	// Moon phase
	switch(get_option('widget_ephemeris_moon_phase')) {

	case 'large':
		$moon_phase = '<option value="large" selected="selected">' . __('Large', 'ephemeris') . '</option><option value="small">' . __('Small', 'ephemeris') . '</option><option value="hide">' . __('Hide', 'ephemeris') . '</option>';
		break;

	case 'small':
		$moon_phase = '<option value="large">' . __('Large', 'ephemeris') . '</option><option value="small" selected="selected">' . __('Small', 'ephemeris') . '</option><option value="hide">' . __('Hide', 'ephemeris') . '</option>';
		break;

	case 'hide':
		$moon_phase = '<option value="large">' . __('Large', 'ephemeris') . '</option><option value="small">' . __('Small', 'ephemeris') . '</option><option value="hide" selected="selected">' . __('Hide', 'ephemeris') . '</option>';
		break;
	}

	// The form fields
	echo '<label for="widget-ephemeris-title">' . __('Title: ', 'ephemeris') . '<br /><input type="text" class="widefat" id="widget-ephemeris-title" name="widget-ephemeris-title" value="' . $title . '" /></label><br />';
	echo '<br />';
	echo '<label for="widget-ephemeris-alignment">' . __('Alignment: ', 'ephemeris') . '<br /><select id="widget-ephemeris-alignment" name="widget-ephemeris-alignment">' . $alignment . '</select></label><br />';
	echo '<br />';
	echo '<label for="widget-ephemeris-sun-zodiac">' . __('Sun sign: ', 'ephemeris') . '<br /><select id="widget-ephemeris-sun-zodiac" name="widget-ephemeris-sun-zodiac">' . $sun_zodiac . '</select></label><br />';
	echo '<br />';
	echo '<label for="widget-ephemeris-moon-zodiac">' . __('Moon sign: ', 'ephemeris') . '<br /><select id="widget-ephemeris-moon-zodiac" name="widget-ephemeris-moon-zodiac">' . $moon_zodiac . '</select></label><br />';
	echo '<br />';
	echo '<label for="widget-ephemeris-moon-phase">' . __('Moon phase: ', 'ephemeris') . '<br /><select id="widget-ephemeris-moon-phase" name="widget-ephemeris-moon-phase">' . $moon_phase . '</select></label><br />';
	echo '<br />';
	echo '<input type="hidden" id="widget-ephemeris-submit" name="widget-ephemeris-submit" value="1" />';
}



function widget_ephemeris_init() {

	if(function_exists('register_sidebar_widget')) {
		register_sidebar_widget('Ephemeris', 'widget_ephemeris_display');
	}

	if(function_exists('register_widget_control')) {
		register_widget_control(array('Ephemeris', 'widgets'), 'widget_ephemeris_control');
	}
}



function widget_ephemeris_activate() {

	// Load language file
	$current_locale = get_locale();
	if(!empty($current_locale)) {
		$mo_file = dirname(__FILE__) . '/languages/ephemeris-' . $current_locale . ".mo";
		if(@file_exists($mo_file) && is_readable($mo_file)) {
			load_textdomain('ephemeris', $mo_file);
		}
	}

	update_option('widget_ephemeris_title', __('Ephemeris', 'ephemeris'));
	update_option('widget_ephemeris_alignment', 'left');
	update_option('widget_ephemeris_moon_phase', 'small');
	update_option('widget_ephemeris_moon_zodiac', 'small');
	update_option('widget_ephemeris_sun_zodiac', 'small');
}



function widget_ephemeris_deactivate() {

	delete_option('widget_ephemeris_title');
	delete_option('widget_ephemeris_alignment');
	delete_option('widget_ephemeris_moon_phase');
	delete_option('widget_ephemeris_moon_zodiac');
	delete_option('widget_ephemeris_sun_zodiac');
}



add_action('plugins_loaded', 'widget_ephemeris_init');
register_activation_hook(__FILE__, 'widget_ephemeris_activate');
register_deactivation_hook(__FILE__, 'widget_ephemeris_deactivate');

?>